==> rstudio_1.3.1093.orig.tar.gz: rstudio-1.3.1093/src/cpp/core/dev/Main.cpp <==
/*
 * Main.cpp
 *
 * Copyright (C) 2009-12 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

#include <iostream>
#include <fstream>

#include <boost/test/minimal.hpp>

#include <shared_core/Error.hpp>
#include <core/Log.hpp>
#include <core/system/System.hpp>


#include <core/r_util/RSessionContext.hpp>

using namespace rstudio;
using namespace rstudio::core;

int test_main(int argc, char * argv[])
{
   try
   { 
      // setup log
      log::setLogLevel(log::LogLevel::WARN);
      log::setProgramId("coredev")
      system::initializeStderrLog("coredev", log::LogLevel::WARN);

      // ignore sigpipe
      Error error = core::system::ignoreSignal(core::system::SigPipe);
      if (error)
         LOG_ERROR(error);


      r_util::SessionContext context(
          "jsmith", r_util::SessionScope("~/finance/reports/q1-final", "45"));

      std::string file = r_util::sessionContextToStreamFile(context);
      std::cerr << file << std::endl;

      r_util::SessionContext context2 = r_util::streamFileToSessionContext(file);

      BOOST_CHECK(context == context2);

      return EXIT_SUCCESS;
   }
   CATCH_UNEXPECTED_EXCEPTION
   
   // if we got this far we had an unexpected exception
   return EXIT_FAILURE ;
}

==> rstudio-2022.02.3-492.tar.gz: rstudio-2022.02.3-492/src/cpp/core/dev/Main.cpp <==
/*
 * Main.cpp
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

#include <iostream>
#include <fstream>

#include <boost/test/minimal.hpp>

#include <shared_core/Error.hpp>
#include <core/Log.hpp>
#include <core/FileSerializer.hpp>
#include <core/system/System.hpp>

#include <core/r_util/RVersionsPosix.hpp>

using namespace rstudio;
using namespace rstudio::core;

int test_main(int argc, char * argv[])
{
   try
   { 
      // setup log
      log::setLogLevel(log::LogLevel::WARN);
      log::setProgramId("coredev")
      system::initializeStderrLog("coredev", log::LogLevel::WARN);

      // ignore sigpipe
      Error error = core::system::ignoreSignal(core::system::SigPipe);
      if (error)
         LOG_ERROR(error);

      using namespace r_util;
      std::vector<RVersion> versions;
      error = readRVersionsFromFile(FilePath("rstudio-some-r-versions"), &versions);
      if (error)
         return core::system::exitFailure(error, ERROR_LOCATION);


      RVersion version = selectVersion("3.1.0", "/opt/R/3.1.0/lib/R", versions);


      std::cerr << version << std::endl;


      return EXIT_SUCCESS;
   }
   CATCH_UNEXPECTED_EXCEPTION
   
   // if we got this far we had an unexpected exception
   return EXIT_FAILURE;
}
